==> developer-center-api-1.8.6-20170315.071643-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/statistics/AerosolConsumerDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.statistics;

import cn.com.duiba.developer.center.api.domain.dto.AerosolLinkDto;
import com.google.common.collect.Lists;

import java.io.Serializable;
import java.util.List;

/**
 * Created by liuyao on 2017/3/15.
 */
public class AerosolConsumerDto implements Serializable {

    private static final long serialVersionUID = 2243699826251427647L;
    private Boolean show;
    private List<AerosolLinkDto> linkList = Lists.newArrayList();
    private String imageList;//逗号分隔
    private String htmlUrl;
    private String jsUrl;
    private String cssUrl;

    private String message;//浮标不展示的原因

    public Boolean getShow() {
        return show;
    }

    public void setShow(Boolean show) {
        this.show = show;
    }

    public List<AerosolLinkDto> getLinkList() {
        return linkList;
    }

    public void setLinkList(List<AerosolLinkDto> linkList) {
        this.linkList = linkList;
    }

    public String getImageList() {
        return imageList;
    }

    public void setImageList(String imageList) {
        this.imageList = imageList;
    }

    public String getHtmlUrl() {
        return htmlUrl;
    }

    public void setHtmlUrl(String htmlUrl) {
        this.htmlUrl = htmlUrl;
    }

    public String getJsUrl() {
        return jsUrl;
    }

    public void setJsUrl(String jsUrl) {
        this.jsUrl = jsUrl;
    }

    public String getCssUrl() {
        return cssUrl;
    }

    public void setCssUrl(String cssUrl) {
        this.cssUrl = cssUrl;
    }
    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

}

==> developer-center-api-3.6.13-sources.jar: cn/com/duiba/developer/center/api/domain/dto/statistics/AerosolConsumerDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.statistics;

import cn.com.duiba.developer.center.api.domain.dto.AerosolLinkDto;
import com.google.common.collect.Lists;

import java.io.Serializable;
import java.util.List;

/**
 * Created by liuyao on 2017/3/15.
 */
public class AerosolConsumerDto implements Serializable {

    private static final long serialVersionUID = 2243699826251427647L;
    private Boolean show;
    private List<AerosolLinkDto> linkList = Lists.newArrayList();
    private String imageList;//逗号分隔
    private String htmlUrl;
    private String jsUrl = "//yun.duiba.com.cn/webapp/js/aerosol-default-90.js";
    private String cssUrl;

    private String message;//浮标不展示的原因

    public Boolean getShow() {
        return show;
    }

    public void setShow(Boolean show) {
        this.show = show;
    }

    public List<AerosolLinkDto> getLinkList() {
        return linkList;
    }

    public void setLinkList(List<AerosolLinkDto> linkList) {
        this.linkList = linkList;
    }

    public String getImageList() {
        return imageList;
    }

    public void setImageList(String imageList) {
        this.imageList = imageList;
    }

    public String getHtmlUrl() {
        return htmlUrl;
    }

    public void setHtmlUrl(String htmlUrl) {
        this.htmlUrl = htmlUrl;
    }

    public String getJsUrl() {
        return jsUrl;
    }

    public void setJsUrl(String jsUrl) {
        this.jsUrl = jsUrl;
    }

    public String getCssUrl() {
        return cssUrl;
    }

    public void setCssUrl(String cssUrl) {
        this.cssUrl = cssUrl;
    }
    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

}
